.. Copyright (C) 2013-2017 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2014-2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.auth`` role allows you to manage and configure basic user
authentication and authorization on configured host, including setting up
system groups with elevated privileges.
